DockGroup class
A leaf node holding a group of tabbed panels.
Properties
- activeIndex ↔ int
-
getter/setter pair
- activePanel → DockPanel?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
-
panels
→ List<
DockPanel> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< DockPanel> ? panels, int? activeIndex}) → DockGroup -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited